AntdSegmentedItem class

分段项 @l AntdSegmented

Constructors

AntdSegmentedItem({dynamic value, bool? disabled, Widget? child})
const

Properties

child Widget?
分段项中显示的子组件,通常是文字或图标
final
disabled bool?
是否禁用该分段项,禁用时不可点击且样式变灰
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
绑定的value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited