AntdSlider class

@t 滑动输入条 @g 信息录入 @o 50 @d 滑动型输入器,展示当前值和可选范围。 @u 当用户需要在数值区间/自定义区间内进行选择时,可为连续或离散值。

Inheritance

Constructors

AntdSlider({Key? key, AntdSliderStyle? style, AntdStyleBuilder<AntdSliderStyle, AntdSlider>? styleBuilder, bool? disabled, bool? readOnly, AntdSliderValue? value, bool? autoCollect = true, ValueChanged<AntdSliderValue?>? onChange, bool? shouldTriggerChange = true, AntdHapticFeedback? hapticFeedback = AntdHapticFeedback.light, bool? manual, Widget? slider, int? max, int? min, bool range = false, int step = 1, int length = 100, bool ticks = false, AntdSliderRenderTicks? renderTicks})
const

Properties

autoCollect bool?
自动同步值到表单
finalinherited
bindWidget Widget
no setterinherited
disabled bool?
禁用
finalinherited
hapticFeedback AntdHapticFeedback?
开启反馈
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
length int
长度
final
manual bool?
受控模式 value的值必须手动更新 默认不开启
finalinherited
max int?
最大值
final
min int?
最小值
final
onChange ValueChanged<AntdSliderValue?>?
变更事件
finalinherited
range bool
是否为双滑块
final
readOnly bool?
只读
finalinherited
renderTicks AntdSliderRenderTicks?
渲染的tick
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldTriggerChange bool?
当value手动控制的时候 是否应该触发onChange
finalinherited
slider Widget?
滑块的图标
final
step int
步距,取值必须大于 0,并且 (max - min) 可被 step 整除。当 marks 不为空对象时,step 的配置失效
final
style AntdSliderStyle?
样式
finalinherited
styleBuilder AntdStyleBuilder<AntdSliderStyle, AntdSlider>?
动态样式
finalinherited
ticks bool
是否显示刻度
final
value AntdSliderValue?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDefaultStyle(BuildContext context, AntdTheme theme, AntdMapToken token) AntdSliderStyle
override
getFinalStyle(BuildContext context, AntdSliderStyle style, AntdMapToken token) AntdSliderStyle
inherited
getInputStyle(BuildContext context) AntdSliderStyle?
inherited
getStyle(BuildContext context) AntdSliderStyle
inherited
getStyleBuilder(BuildContext context) AntdStyleBuilder<AntdSliderStyle, AntdSlider>?
inherited
getThemeStyle(BuildContext context, AntdTheme theme) AntdStyleBuilder<AntdSliderStyle, AntdSlider>?
override
getValue(BuildContext context) → dynamic
inherited
getWidget(BuildContext context) AntdSlider
override
isFromItemEnv(BuildContext context) bool
inherited
margeStyle(AntdSliderStyle defaultStyle, AntdSliderStyle? style) AntdSliderStyle
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(BuildContext context, dynamic value, AntdFormTrigger sourceTrigger) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited