AntdScrollToIndexConfig class

Constructors

AntdScrollToIndexConfig({bool jump = true, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.easeOut, AntdEdge viewportAlign = AntdEdge.start, AntdEdge itemAlign = AntdEdge.start, bool set = false, int getTargetSize(int total)?})
const

Properties

curve Curve
final
duration Duration
final
getTargetSize int Function(int total)?
final
hashCode int
The hash code for this object.
no setterinherited
itemAlign AntdEdge
final
jump bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
set bool
final
viewportAlign AntdEdge
final

Methods

copyWith({bool? jump, Duration? duration, Curve? curve, AntdEdge? viewportAlign, AntdEdge? itemAlign, bool? set, int getTargetSize(int total)?}) AntdScrollToIndexConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited