AntdSelectorItem class
选择器选项数据类 @l AntdSelector
- Inheritance
Constructors
-
AntdSelectorItem({Key? key, AntdSelectorItemStyle? style, AntdStyleBuilder<
AntdSelectorItemStyle, AntdSelectorItem> ? styleBuilder, bool? disabled, dynamic value, Widget? description, required Widget label}) -
const
Properties
- autoCollect → bool?
-
自动同步值到表单
finalinherited
- bindWidget → Widget
-
no setterinherited
- description → Widget?
-
选项的描述信息组件(显示在label下方)
final
- disabled → bool?
-
禁用
finalinherited
- hapticFeedback → AntdHapticFeedback?
-
开启反馈
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → Widget
-
选项的主标签组件
final
- manual → bool?
-
受控模式 value的值必须手动更新 默认不开启
finalinherited
- onChange → ValueChanged?
-
变更事件
finalinherited
- readOnly → bool?
-
只读
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldTriggerChange → bool?
-
当value手动控制的时候 是否应该触发onChange
finalinherited
- style → AntdSelectorItemStyle?
-
样式
finalinherited
-
styleBuilder
→ AntdStyleBuilder<
AntdSelectorItemStyle, AntdSelectorItem> ? -
动态样式
finalinherited
- value → dynamic
-
值
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getDefaultStyle(
BuildContext context, AntdTheme theme, AntdMapToken token) → AntdSelectorItemStyle -
override
-
getFinalStyle(
BuildContext context, AntdSelectorItemStyle style, AntdMapToken token) → AntdSelectorItemStyle -
inherited
-
getInputStyle(
BuildContext context) → AntdSelectorItemStyle? -
inherited
-
getStyle(
BuildContext context) → AntdSelectorItemStyle -
inherited
-
getStyleBuilder(
BuildContext context) → AntdStyleBuilder< AntdSelectorItemStyle, AntdSelectorItem> ? -
inherited
-
getThemeStyle(
BuildContext context, AntdTheme theme) → AntdStyleBuilder< AntdSelectorItemStyle, AntdSelectorItem> ? -
inherited
-
getValue(
BuildContext context) → dynamic -
inherited
-
getWidget(
BuildContext context) → AntdSelectorItem -
override
-
isFromItemEnv(
BuildContext context) → bool -
inherited
-
margeStyle(
AntdSelectorItemStyle defaultStyle, AntdSelectorItemStyle? style) → AntdSelectorItemStyle -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
BuildContext context, dynamic value, AntdFormTrigger sourceTrigger) → void -
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited