AntdSwipeItem class
Methods
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
inherited
-
copyFrom(AntdSwipeItem other)
→ AntdSwipeItem
-
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
getDefaultStyle(BuildContext context, AntdTheme theme, AntdMapToken token)
→ AntdSwipeItemStyle
-
override
-
getFinalStyle(BuildContext context, AntdSwipeItemStyle style, AntdMapToken token)
→ AntdSwipeItemStyle
-
inherited
-
getInputStyle(BuildContext context)
→ AntdSwipeItemStyle?
-
inherited
-
getStyle(BuildContext context)
→ AntdSwipeItemStyle
-
inherited
-
getStyleBuilder(BuildContext context)
→ AntdStyleBuilder<AntdSwipeItemStyle, AntdSwipeItem>?
-
inherited
-
getThemeStyle(BuildContext context, AntdTheme theme)
→ AntdStyleBuilder<AntdSwipeItemStyle, AntdSwipeItem>?
-
inherited
-
getWidget(BuildContext context)
→ AntdSwipeItem
-
override
-
margeStyle(AntdSwipeItemStyle defaultStyle, AntdSwipeItemStyle? style)
→ AntdSwipeItemStyle
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
render(BuildContext context, AntdSwipeItemStyle style)
→ Widget
-
override
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited